@@ -11,7 +11,11 @@ class JsonIOMixin:
     """Save/load a array into a JSON file."""
 
     def save_json(
-        self, file: Union[str, TextIO], protocol: str = 'jsonschema', **kwargs
+        self,
+        file: Union[str, TextIO],
+        protocol: str = 'jsonschema',
+        encoding: str = 'utf-8',
+        **kwargs
     ) -> None:
         """Save array elements into a JSON file.
 
@@ -19,11 +23,12 @@ class JsonIOMixin:
 
         :param file: File or filename to which the data is saved.
         :param protocol: `jsonschema` or `protobuf`
+        :param encoding: encoding used to save data into a JSON file. By default, ``utf-8`` is used.
         """
         if hasattr(file, 'write'):
             file_ctx = nullcontext(file)
         else:
-            file_ctx = open(file, 'w')
+            file_ctx = open(file, 'w', encoding=encoding)
 
         with file_ctx as fp:
             for d in self:
@@ -32,12 +37,18 @@ class JsonIOMixin:
 
     @classmethod
     def load_json(
-        cls: Type['T'], file: Union[str, TextIO], protocol: str = 'jsonschema', **kwargs
+        cls: Type['T'],
+        file: Union[str, TextIO],
+        protocol: str = 'jsonschema',
+        encoding: str = 'utf-8',
+        **kwargs
     ) -> 'T':
         """Load array elements from a JSON file.
 
         :param file: File or filename or a JSON string to which the data is saved.
         :param protocol: `jsonschema` or `protobuf`
+        :param encoding: encoding used to load data from a JSON file. By default, ``utf-8`` is used.
+
         :return: a DocumentArrayLike object
         """
 
@@ -47,7 +58,7 @@ class JsonIOMixin:
         if hasattr(file, 'read'):
             file_ctx = nullcontext(file)
         elif os.path.exists(file):
-            file_ctx = open(file)
+            file_ctx = open(file, 'r', encoding=encoding)
         else:
             file_ctx = nullcontext(json.loads(file))
             constructor = Document.from_dict
@@ -57,9 +68,13 @@ class JsonIOMixin:
 
     @classmethod
     def from_json(
-        cls: Type['T'], file: Union[str, TextIO], protocol: str = 'jsonschema', **kwargs
+        cls: Type['T'],
+        file: Union[str, bytes, bytearray, TextIO],
+        protocol: str = 'jsonschema',
+        encoding: str = 'utf-8',
+        **kwargs
     ) -> 'T':
-        return cls.load_json(file, protocol=protocol, **kwargs)
+        return cls.load_json(file, protocol=protocol, encoding=encoding, **kwargs)
 
     @classmethod
     def from_list(
